NEWS
======

## 0.3.0 - 2023-04-15 <a id='0.3.0'></a>

### Added

- add bump subcommand
- add provisional and untested `--entry-only` option to `dev-srpm` subcommand
- add RPM specfile
- add NEWS.md

### Fixed

- improve CLI exception handling
- sync subcommand: fix changelog preservation and truncate file

## 0.2.0 - 2022-03-18 <a id='0.2.0'></a>

### Added

- add --clean flag to `dev-srpm` subcommand
- add `sync` subcommand

### Fixed

- improve error handling and make `--last-ref` optional
